import { z } from "../zod";

// 密码验证Schema
export const signupPasswordSchema = z.string().min(8)
    .regex(/^(?=.*[A-Za-z])(?=.*\d)/, { message: '密码必须包含至少一个字母和一个数字' })
    .openapi({ description: '用户密码（至少8个字符，包含字母和数字）' });

// 用户注册验证Schema
export const registerUserSchema = z.object({
    email: z.string().email().openapi({ description: '用户电子邮箱' }),
    name: z.string().min(2).openapi({ description: '用户名称' }),
    password: z.string().min(6).openapi({ description: '用户密码' }),
    phone: z.string().optional().openapi({ description: '电话号码（可选）' }),
    avatar: z.string().optional().openapi({ description: '头像URL（可选）' }),
}).openapi({ title: 'RegisterUser', description: '用户注册信息' });


// 用户登录验证Schema
export const loginUserSchema = z.object({
    email: z.string().email().openapi({ description: '用户电子邮箱' }),
    password: z.string().openapi({ description: '用户密码' }),
}).openapi({ title: 'LoginUser', description: '用户登录信息' });

// 用户信息响应Schema
export const userResponseSchema = z.object({
    id: z.string().openapi({ description: '用户ID' }),
    email: z.string().email().openapi({ description: '用户电子邮箱' }),
    name: z.string().openapi({ description: '用户名称' }),
    phone: z.string().optional().nullable().openapi({ description: '电话号码' }),
    avatar: z.string().optional().nullable().openapi({ description: '头像URL' }),
    createdTime: z.date().optional().openapi({ description: '创建时间' }),
    updatedTime: z.date().optional().openapi({ description: '更新时间' }),
}).openapi({ title: 'UserResponse', description: '用户信息响应' });

// 登录响应Schema
export const loginResponseSchema = z.object({
    access_token: z.string().openapi({ description: '访问令牌' }),
    token_type: z.string().openapi({ description: '令牌类型' }),
    expires_in: z.number().openapi({ description: '过期时间（秒）' }),
    user: userResponseSchema,
}).openapi({ title: 'LoginResponse', description: '登录成功响应' });

// 类型导出
export type RegisterUserDto = z.infer<typeof registerUserSchema>;
export type LoginUserDto = z.infer<typeof loginUserSchema>;
export type UserResponse = z.infer<typeof userResponseSchema>;
export type LoginResponse = z.infer<typeof loginResponseSchema>;
